@@ -1182,7 +1182,7 @@ class SentenceRecognitionRequest(AbstractModel):
         :type EngSerViceType: str
         :param SourceType: 语音数据来源。0：语音 URL；1：语音数据（post body）。
         :type SourceType: int
-        :param VoiceFormat: 识别音频的音频格式。mp3、wav。
+        :param VoiceFormat: 识别音频的音频格式，支持wav、pcm、ogg-opus、speex、silk、mp3、m4a、aac。
         :type VoiceFormat: str
         :param UsrAudioKey: 用户端对此任务的唯一标识，用户自助生成，用于用户查找识别结果。
         :type UsrAudioKey: str
@@ -1428,7 +1428,7 @@ class Task(AbstractModel):
 
 
 class TaskStatus(AbstractModel):
-    """获取录音识别结果结果的返回参数
+    """获取录音识别结果的返回参数
 
     """
 
